# coding: utf-8

"""
    Trieve API

    Trieve OpenAPI Specification. This document describes all of the operations available through the Trieve API.

    The version of the OpenAPI document: 0.12.0
    Contact: developers@trieve.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from trieve_py_client.models.crawl_interval import CrawlInterval
from trieve_py_client.models.scrape_options import ScrapeOptions
from typing import Optional, Set
from typing_extensions import Self

class CrawlOptions(BaseModel):
    """
    Options for setting up the crawl which will populate the dataset.
    """ # noqa: E501
    allow_external_links: Optional[StrictBool] = Field(default=None, description="Option for allowing the crawl to follow links to external websites.")
    body_remove_strings: Optional[List[StrictStr]] = Field(default=None, description="Text strings to remove from body when creating chunks for each page")
    boost_titles: Optional[StrictBool] = Field(default=None, description="Boost titles such that keyword matches in titles are prioritized in search results. Strongly recommended to leave this on. Defaults to true.")
    exclude_paths: Optional[List[StrictStr]] = Field(default=None, description="URL Patterns to exclude from the crawl")
    exclude_tags: Optional[List[StrictStr]] = Field(default=None, description="Specify the HTML tags, classes and ids to exclude from the response.")
    heading_remove_strings: Optional[List[StrictStr]] = Field(default=None, description="Text strings to remove from headings when creating chunks for each page")
    ignore_sitemap: Optional[StrictBool] = Field(default=None, description="Ignore the website sitemap when crawling, defaults to true.")
    include_paths: Optional[List[StrictStr]] = Field(default=None, description="URL Patterns to include in the crawl")
    include_tags: Optional[List[StrictStr]] = Field(default=None, description="Specify the HTML tags, classes and ids to include in the response.")
    interval: Optional[CrawlInterval] = None
    limit: Optional[StrictInt] = Field(default=None, description="How many pages to crawl, defaults to 1000")
    scrape_options: Optional[ScrapeOptions] = None
    site_url: Optional[StrictStr] = Field(default=None, description="The URL to crawl")
    __properties: ClassVar[List[str]] = ["allow_external_links", "body_remove_strings", "boost_titles", "exclude_paths", "exclude_tags", "heading_remove_strings", "ignore_sitemap", "include_paths", "include_tags", "interval", "limit", "scrape_options", "site_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CrawlOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scrape_options
        if self.scrape_options:
            _dict['scrape_options'] = self.scrape_options.to_dict()
        # set to None if allow_external_links (nullable) is None
        # and model_fields_set contains the field
        if self.allow_external_links is None and "allow_external_links" in self.model_fields_set:
            _dict['allow_external_links'] = None

        # set to None if body_remove_strings (nullable) is None
        # and model_fields_set contains the field
        if self.body_remove_strings is None and "body_remove_strings" in self.model_fields_set:
            _dict['body_remove_strings'] = None

        # set to None if boost_titles (nullable) is None
        # and model_fields_set contains the field
        if self.boost_titles is None and "boost_titles" in self.model_fields_set:
            _dict['boost_titles'] = None

        # set to None if exclude_paths (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_paths is None and "exclude_paths" in self.model_fields_set:
            _dict['exclude_paths'] = None

        # set to None if exclude_tags (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_tags is None and "exclude_tags" in self.model_fields_set:
            _dict['exclude_tags'] = None

        # set to None if heading_remove_strings (nullable) is None
        # and model_fields_set contains the field
        if self.heading_remove_strings is None and "heading_remove_strings" in self.model_fields_set:
            _dict['heading_remove_strings'] = None

        # set to None if ignore_sitemap (nullable) is None
        # and model_fields_set contains the field
        if self.ignore_sitemap is None and "ignore_sitemap" in self.model_fields_set:
            _dict['ignore_sitemap'] = None

        # set to None if include_paths (nullable) is None
        # and model_fields_set contains the field
        if self.include_paths is None and "include_paths" in self.model_fields_set:
            _dict['include_paths'] = None

        # set to None if include_tags (nullable) is None
        # and model_fields_set contains the field
        if self.include_tags is None and "include_tags" in self.model_fields_set:
            _dict['include_tags'] = None

        # set to None if interval (nullable) is None
        # and model_fields_set contains the field
        if self.interval is None and "interval" in self.model_fields_set:
            _dict['interval'] = None

        # set to None if limit (nullable) is None
        # and model_fields_set contains the field
        if self.limit is None and "limit" in self.model_fields_set:
            _dict['limit'] = None

        # set to None if scrape_options (nullable) is None
        # and model_fields_set contains the field
        if self.scrape_options is None and "scrape_options" in self.model_fields_set:
            _dict['scrape_options'] = None

        # set to None if site_url (nullable) is None
        # and model_fields_set contains the field
        if self.site_url is None and "site_url" in self.model_fields_set:
            _dict['site_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CrawlOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_external_links": obj.get("allow_external_links"),
            "body_remove_strings": obj.get("body_remove_strings"),
            "boost_titles": obj.get("boost_titles"),
            "exclude_paths": obj.get("exclude_paths"),
            "exclude_tags": obj.get("exclude_tags"),
            "heading_remove_strings": obj.get("heading_remove_strings"),
            "ignore_sitemap": obj.get("ignore_sitemap"),
            "include_paths": obj.get("include_paths"),
            "include_tags": obj.get("include_tags"),
            "interval": obj.get("interval"),
            "limit": obj.get("limit"),
            "scrape_options": ScrapeOptions.from_dict(obj["scrape_options"]) if obj.get("scrape_options") is not None else None,
            "site_url": obj.get("site_url")
        })
        return _obj


